==> edc-document-status-0.1.4.tar.gz: edc-document-status-0.1.4/runtests.py <==
#!/usr/bin/env python
import logging
import os
import sys
from os.path import abspath, dirname

import django
from django.conf import settings
from django.test.runner import DiscoverRunner
from edc_test_utils import DefaultTestSettings

app_name = "edc_document_status"
base_dir = dirname(abspath(__file__))

DEFAULT_SETTINGS = DefaultTestSettings(
    calling_file=__file__,
    BASE_DIR=base_dir,
    APP_NAME=app_name,
    ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
    SUBJECT_VISIT_MODEL="visit_schedule_app.subjectvisit",
    INSTALLED_APPS=[
        "django.contrib.admin",
        "django.contrib.auth",
        "django.contrib.contenttypes",
        "django.contrib.messages",
        "django.contrib.sessions",
        "django.contrib.sites",
        "django.contrib.staticfiles",
        "django_crypto_fields.apps.AppConfig",
        "django_revision.apps.AppConfig",
        "multisite",
        # "edc_action_item.apps.AppConfig",
        # "edc_appointment.apps.AppConfig",
        # "edc_consent.apps.AppConfig",
        # "edc_device.apps.AppConfig",
        # "edc_export.apps.AppConfig",
        # "edc_facility.apps.AppConfig",
        # "edc_identifier.apps.AppConfig",
        # "edc_metadata.apps.AppConfig",
        # "edc_notification.apps.AppConfig",
        # "edc_protocol.apps.AppConfig",
        # "edc_reference.apps.AppConfig",
        # "edc_registration.apps.AppConfig",
        # "edc_sites.apps.AppConfig",
        # "edc_timepoint.apps.AppConfig",
        # "edc_visit_schedule.apps.AppConfig",
        # "visit_schedule_app.apps.AppConfig",
        # "edc_visit_tracking.apps.AppConfig",
        # "edc_crf.apps.AppConfig",
        "edc_document_status.apps.AppConfig",
    ],
    add_dashboard_middleware=True,
).settings


def main():
    if not settings.configured:
        settings.configure(**DEFAULT_SETTINGS)
    django.setup()
    tags = [t.split("=")[1] for t in sys.argv if t.startswith("--tag")]
    failfast = True if [t for t in sys.argv if t == "--failfast"] else False
    failures = DiscoverRunner(failfast=failfast, tags=tags).run_tests([f"{app_name}.tests"])
    sys.exit(bool(failures))


if __name__ == "__main__":
    logging.basicConfig()
    main()

==> edc-document-status-0.1.6.tar.gz: edc-document-status-0.1.6/runtests.py <==
#!/usr/bin/env python
import logging
import os
import sys
from os.path import abspath, dirname

import django
from django.conf import settings
from django.test.runner import DiscoverRunner
from edc_test_utils import DefaultTestSettings

app_name = "edc_document_status"
base_dir = dirname(abspath(__file__))

DEFAULT_SETTINGS = DefaultTestSettings(
    calling_file=__file__,
    BASE_DIR=base_dir,
    APP_NAME=app_name,
    ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
    SUBJECT_VISIT_MODEL="edc_visit_tracking.subjectvisit",
    INSTALLED_APPS=[
        "django.contrib.admin",
        "django.contrib.auth",
        "django.contrib.contenttypes",
        "django.contrib.messages",
        "django.contrib.sessions",
        "django.contrib.sites",
        "django.contrib.staticfiles",
        "django_crypto_fields.apps.AppConfig",
        "django_revision.apps.AppConfig",
        "multisite",
        # "edc_action_item.apps.AppConfig",
        # "edc_appointment.apps.AppConfig",
        # "edc_consent.apps.AppConfig",
        # "edc_device.apps.AppConfig",
        # "edc_export.apps.AppConfig",
        # "edc_facility.apps.AppConfig",
        # "edc_identifier.apps.AppConfig",
        # "edc_metadata.apps.AppConfig",
        # "edc_notification.apps.AppConfig",
        # "edc_protocol.apps.AppConfig",
        # "edc_reference.apps.AppConfig",
        # "edc_registration.apps.AppConfig",
        # "edc_sites.apps.AppConfig",
        # "edc_timepoint.apps.AppConfig",
        # "edc_visit_schedule.apps.AppConfig",
        # "visit_schedule_app.apps.AppConfig",
        # "edc_visit_tracking.apps.AppConfig",
        # "edc_crf.apps.AppConfig",
        "edc_document_status.apps.AppConfig",
    ],
    add_dashboard_middleware=True,
).settings


def main():
    if not settings.configured:
        settings.configure(**DEFAULT_SETTINGS)
    django.setup()
    tags = [t.split("=")[1] for t in sys.argv if t.startswith("--tag")]
    failfast = True if [t for t in sys.argv if t == "--failfast"] else False
    failures = DiscoverRunner(failfast=failfast, tags=tags).run_tests([f"{app_name}.tests"])
    sys.exit(bool(failures))


if __name__ == "__main__":
    logging.basicConfig()
    main()
